@@ -35,7 +35,7 @@ spectra <- sc.results$fspectra # Filtered list of mass spectra
 type <- sc.results$fmeta # Filtered metadata
 
 ## ----deno, echo=TRUE, eval=TRUE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-spectra <- transfIntensity(spectra, fun = function(x) sqrt(x))
+spectra <- transfIntensity(spectra, fun = sqrt)
 spectra <- wavSmoothing(spectra, thresh.scale = thScale)
 spectra <- removeBaseline(spectra, method = "SNIP", iterations = ite)
 spectra <- calibrateIntensity(spectra, method = "PQN")
